Crate vmi_core

Crate vmi_core 

Core VMI functionality.

Re-exports

pub use self::arch::Architecture;
pub use self::arch::Registers;
pub use self::driver::VmiDriver;
pub use self::driver::VmiEventControl;
pub use self::driver::VmiFullDriver;
pub use self::driver::VmiMemory;
pub use self::driver::VmiProtection;
pub use self::driver::VmiQueryProtection;
pub use self::driver::VmiQueryRegisters;
pub use self::driver::VmiRead;
pub use self::driver::VmiReadAccess;
pub use self::driver::VmiRegisters;
pub use self::driver::VmiSetProtection;
pub use self::driver::VmiSetRegisters;
pub use self::driver::VmiViewControl;
pub use self::driver::VmiVmControl;
pub use self::driver::VmiWrite;
pub use self::driver::VmiWriteAccess;
pub use self::os::VmiOs;
pub use self::os::VmiOsExt;

Modules

arch
Architecture abstraction
driver
VMI driver trait hierarchy.
os
OS introspection
trace
Field-shaped accessors for #[tracing::instrument(fields(...))].

Macros

vmi_probe
Probes a single read expression through a VmiProber, returning Ok(None) if it page-faults.

Structs

AccessContext
Defines the context for memory access operations in VMI.
AddressContext
A complete address context within a system for virtual to physical address translation.
Gfn
A Guest Frame Number.
MemoryAccess
Memory access permission flags.
MemoryAccessOptions
Options for controlling memory access monitoring.
Pa
A Guest Physical Address.
Va
A Guest Virtual Address.
VcpuId
A virtual CPU identifier.
View
A physical memory view identifier.
VmiContext
A VMI context.
VmiCore
The core functionality for Virtual Machine Introspection (VMI).
VmiEvent
An event that occurred during VMI.
VmiEventFlags
Flags that can be set in a VMI event.
VmiEventResponse
A response to a VMI event.
VmiInfo
Represents information about the VMI.
VmiMappedPage
A page of memory that has been mapped from the guest virtual machine.
VmiOsContext
Wrapper providing access to OS-specific operations.
VmiOsState
Wrapper providing access to OS-specific operations.
VmiPauseGuard
A guard that pauses the virtual machine on creation and resumes it on drop.
VmiProber
Batches the page faults raised by a sequence of memory reads so they can be injected together, while skipping pages already known to be unserviceable.
VmiSession
A VMI session.
VmiSessionPauseGuard
A guard that pauses the virtual machine and snapshots the boot CPU registers on creation, then resumes the VM on drop.
VmiState
A VMI state.

Enums

TranslationMechanism
The mechanism used for translating virtual addresses to physical addresses.
VmiError
An error that can occur when working with the VMI.
VmiEventAction
The primary action to take when resuming from a VMI event.

Traits

VmiHandler
A trait for handling VMI events.
VmiVa
A trait for types that have a virtual address.