pub enum VmiError {
}Expand description
An error that can occur when working with the VMI.
Variants
Driver(Box<dyn Error + Send + Sync>)
An error occurred in the VMI driver.
Os(Box<dyn Error + Send + Sync>)
An OS-specific error occurred.
Io(Error)
An I/O error occurred.
Isr(Error)
An error occurred while parsing symbols.
Translation(PageFaults)
A translation error occurred.
InvalidAddressWidth
The given address has invalid width.
InvalidTimeout
Invalid timeout.
NotSupported
Operation not supported.
OutOfBounds
Out of bounds.
RootNotPresent
Translation root not present.
Timeout
Operation timed out.
ViewNotFound
The view was not found.
Other(&'static str)
Other error.
Implementations
Sourceimpl VmiError
impl VmiError
Sourcepub fn driver<E>(err: E) -> Self
pub fn driver<E>(err: E) -> Self
Boxes a driver-specific error into VmiError::Driver.
Sourcepub fn os<E>(err: E) -> Self
pub fn os<E>(err: E) -> Self
Boxes an OS-specific error into VmiError::Os.
Sourcepub fn page_fault(pf: impl Into<AddressContext>) -> Self
pub fn page_fault(pf: impl Into<AddressContext>) -> Self
Creates a new page fault error.
Sourcepub fn page_faults(pfs: impl IntoIterator<Item = AddressContext>) -> Self
pub fn page_faults(pfs: impl IntoIterator<Item = AddressContext>) -> Self
Creates a new page fault error with multiple page faults.