VmiOsProcessExt

Trait VmiOsProcessExt 

pub trait VmiOsProcessExt<'a, Driver>: VmiOsProcess<'a, Driver>
where Driver: VmiDriver,
{ // Provided methods fn find_region( &self, predicate: impl RegionPredicate<Self::Os>, ) -> Result<Option<<Self::Os as VmiOs>::Region<'a>>, VmiError> { ... } fn filter_regions( &self, predicate: impl RegionPredicate<Self::Os>, ) -> Result<impl Iterator<Item = Result<<Self::Os as VmiOs>::Region<'a>, VmiError>>, VmiError> { ... } }
Extension methods on VmiOsProcess.

The blanket impl is the only impl of this trait, so implementors of VmiOsProcess cannot override the default bodies.

Provided Methods

fn find_region( &self, predicate: impl RegionPredicate<Self::Os>, ) -> Result<Option<<Self::Os as VmiOs>::Region<'a>>, VmiError>

Returns the first memory region matching predicate, or Ok(None) if no region in the process matches.

fn filter_regions( &self, predicate: impl RegionPredicate<Self::Os>, ) -> Result<impl Iterator<Item = Result<<Self::Os as VmiOs>::Region<'a>, VmiError>>, VmiError>

Returns an iterator over the memory regions matching predicate.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, Driver, T> VmiOsProcessExt<'a, Driver> for T
where Driver: VmiDriver, T: VmiOsProcess<'a, Driver>,