VmiOsUserModule

Trait VmiOsUserModule 

pub trait VmiOsUserModule<'a, Driver>: VmiVa + 'a
where Driver: VmiDriver,
{ type Os: VmiOs<Driver = Driver>; // Required methods fn base_address(&self) -> Result<Va, VmiError>; fn size(&self) -> Result<u64, VmiError>; fn name(&self) -> Result<String, VmiError>; }
A trait for user-mode modules.

This trait provides an abstraction over modules loaded into a process address space, such as executables and shared libraries.

Required Associated Types

type Os: VmiOs<Driver = Driver>

The VMI OS type.

Required Methods

fn base_address(&self) -> Result<Va, VmiError>

Returns the base address of the module.

Platform-specific
  • Windows: LDR_DATA_TABLE_ENTRY.DllBase
fn size(&self) -> Result<u64, VmiError>

Returns the size of the module.

Platform-specific
  • Windows: LDR_DATA_TABLE_ENTRY.SizeOfImage
fn name(&self) -> Result<String, VmiError>

Returns the name of the module.

Platform-specific
  • Windows: LDR_DATA_TABLE_ENTRY.BaseDllName

Implementors

Source

impl<Driver> VmiOsUserModule<'_, Driver> for NoOS<Driver>
where Driver: VmiDriver,

Source

type Os = NoOS<Driver>