Crate vmi_core

Crate vmi_core 

Core VMI functionality.

Re-exports

pub use self::arch::Architecture;
pub use self::arch::Registers;
pub use self::driver::VmiDriver;
pub use self::driver::VmiEventControl;
pub use self::driver::VmiFullDriver;
pub use self::driver::VmiMemory;
pub use self::driver::VmiProtection;
pub use self::driver::VmiQueryProtection;
pub use self::driver::VmiQueryRegisters;
pub use self::driver::VmiRead;
pub use self::driver::VmiReadAccess;
pub use self::driver::VmiRegisters;
pub use self::driver::VmiSetProtection;
pub use self::driver::VmiSetRegisters;
pub use self::driver::VmiViewControl;
pub use self::driver::VmiVmControl;
pub use self::driver::VmiWrite;
pub use self::driver::VmiWriteAccess;
pub use self::os::VmiOs;

Modules

arch
Architecture abstraction
driver
VMI driver trait hierarchy.
os
OS introspection

Macros

vmi_probe
Probes for safely handling page faults during memory access operations.

Structs

AccessContext
Defines the context for memory access operations in VMI.
AddressContext
A complete address context within a system for virtual to physical address translation.
Gfn
A Guest Frame Number.
Hex
A hexadecimal representation of a value.
MemoryAccess
Memory access permission flags.
MemoryAccessOptions
Options for controlling memory access monitoring.
Pa
A Guest Physical Address.
Va
A Guest Virtual Address.
VcpuId
A virtual CPU identifier.
View
A physical memory view identifier.
VmiContext
A VMI context.
VmiCore
The core functionality for Virtual Machine Introspection (VMI).
VmiEvent
An event that occurred during VMI.
VmiEventFlags
Flags that can be set in a VMI event.
VmiEventResponse
A response to a VMI event.
VmiInfo
Represents information about the VMI.
VmiMappedPage
A page of memory that has been mapped from the guest virtual machine.
VmiOsContext
Wrapper providing access to OS-specific operations.
VmiOsState
Wrapper providing access to OS-specific operations.
VmiPauseGuard
A guard that pauses the virtual machine on creation and resumes it on drop.
VmiProber
Prober for safely handling page faults during memory access operations.
VmiSession
A VMI session.
VmiState
A VMI state.

Enums

TranslationMechanism
The mechanism used for translating virtual addresses to physical addresses.
VmiError
An error that can occur when working with the VMI.
VmiEventAction
The primary action to take when resuming from a VMI event.

Traits

VmiHandler
A trait for handling VMI events.
VmiVa
A trait for types that have a virtual address.

Type Aliases

PageFaults
A collection of page faults.