pub struct VmiProber { /* private fields */ }Expand description
Prober for safely handling page faults during memory access operations.
Implementations
Sourceimpl VmiProber
impl VmiProber
Sourcepub fn new(restricted: &IndexSet<AddressContext>) -> Self
pub fn new(restricted: &IndexSet<AddressContext>) -> Self
Creates a new prober.
Sourcepub fn probe<T, F>(&self, f: F) -> Result<Option<T>, VmiError>
pub fn probe<T, F>(&self, f: F) -> Result<Option<T>, VmiError>
Probes for safely handling page faults during memory access operations.
Sourcepub fn check_result<T>(
&self,
result: Result<T, VmiError>,
) -> Result<Option<T>, VmiError>
pub fn check_result<T>( &self, result: Result<T, VmiError>, ) -> Result<Option<T>, VmiError>
Handles a result that may contain page faults, returning the value if successful.
Sourcepub fn page_faults(&self) -> IndexSet<AddressContext>
pub fn page_faults(&self) -> IndexSet<AddressContext>
Returns the set of page faults that have occurred that are not in the restricted set.
Sourcepub fn error_for_page_faults(&self) -> Result<(), VmiError>
pub fn error_for_page_faults(&self) -> Result<(), VmiError>
Checks for any unexpected page faults that have occurred and returns an error if any are present.